@@ -1,4 +1,4 @@
-// Copyright (C) 2008-2014 National ICT Australia (NICTA)
+// Copyright (C) 2008-2016 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -231,7 +231,7 @@ SpBase<elem_type, derived>::min(uword& row_of_min_val, uword& col_of_min_val) co
   {
   const SpProxy<derived> P( (*this).get_ref() );
   
-  uword index;
+  uword index = 0;
   
   const elem_type val = spop_min::min_with_index(P, index);
   
@@ -252,7 +252,7 @@ SpBase<elem_type, derived>::max(uword& row_of_max_val, uword& col_of_max_val) co
   {
   const SpProxy<derived> P( (*this).get_ref() );
   
-  uword index;
+  uword index = 0;
   
   const elem_type val = spop_max::max_with_index(P, index);
   
@@ -266,4 +266,52 @@ SpBase<elem_type, derived>::max(uword& row_of_max_val, uword& col_of_max_val) co
 
 
 
+template<typename elem_type, typename derived>
+inline
+arma_warn_unused
+uword
+SpBase<elem_type,derived>::index_min() const
+  {
+  const SpProxy<derived> P( (*this).get_ref() );
+  
+  uword index = 0;
+  
+  if(P.get_n_elem() == 0)
+    {
+    arma_debug_check(true, "index_min(): object has no elements");
+    }
+  else
+    {
+    spop_min::min_with_index(P, index);
+    }
+  
+  return index;
+  }
+
+
+
+template<typename elem_type, typename derived>
+inline
+arma_warn_unused
+uword
+SpBase<elem_type,derived>::index_max() const
+  {
+  const SpProxy<derived> P( (*this).get_ref() );
+  
+  uword index = 0;
+  
+  if(P.get_n_elem() == 0)
+    {
+    arma_debug_check(true, "index_max(): object has no elements");
+    }
+  else
+    {
+    spop_max::max_with_index(P, index);
+    }
+  
+  return index;
+  }
+
+
+
 //! @}
