@@ -1,10 +1,12 @@
-// Copyright (C) 2013-2014 Ryan Curtin
-// Copyright (C) 2013-2014 Conrad Sanderson
-// Copyright (C) 2013-2014 NICTA
+// Copyright (C) 2013-2016 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
+// -------------------------------------------------------------------
+// 
+// Written by Conrad Sanderson - http://conradsanderson.id.au
+// Written by Ryan Curtin
 
 
 //! \addtogroup fn_eigs_sym
@@ -13,6 +15,7 @@
 
 //! eigenvalues of symmetric real sparse matrix X
 template<typename T1>
+arma_warn_unused
 inline
 Col<typename T1::pod_type>
 eigs_sym
@@ -35,7 +38,7 @@ eigs_sym
   if(status == false)
     {
     eigval.reset();
-    arma_bad("eigs_sym(): failed to converge");
+    arma_stop_runtime_error("eigs_sym(): decomposition failed");
     }
   
   return eigval;
@@ -67,7 +70,7 @@ eigs_sym
   if(status == false)
     {
     eigval.reset();
-    arma_bad("eigs_sym(): failed to converge", false);
+    arma_debug_warn("eigs_sym(): decomposition failed");
     }
   
   return status;
@@ -93,14 +96,14 @@ eigs_sym
   arma_extra_debug_sigprint();
   arma_ignore(junk);
   
-  arma_debug_check( void_ptr(&eigval) == void_ptr(&eigvec), "eigs_sym(): eigval is an alias of eigvec" );
+  arma_debug_check( void_ptr(&eigval) == void_ptr(&eigvec), "eigs_sym(): parameter 'eigval' is an alias of parameter 'eigvec'" );
   
   const bool status = sp_auxlib::eigs_sym(eigval, eigvec, X, n_eigvals, form, tol);
   
   if(status == false)
     {
     eigval.reset();
-    arma_bad("eigs_sym(): failed to converge", false);
+    arma_debug_warn("eigs_sym(): decomposition failed");
     }
   
   return status;
