@@ -416,12 +416,106 @@ ind2sub(const SizeMat& s, const uword i)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (i >= (s.n_rows * s.n_cols) ), "ind2sub(): index out of range" );
+  const uword s_n_rows = s.n_rows;
+  
+  arma_debug_check( (i >= (s_n_rows * s.n_cols) ), "ind2sub(): index out of range" );
+  
+  const uword row = i % s_n_rows;
+  const uword col = i / s_n_rows;
   
   uvec out(2);
   
-  out[0] = i % s.n_rows;
-  out[1] = i / s.n_rows;
+  uword* out_mem = out.memptr();
+  
+  out_mem[0] = row;
+  out_mem[1] = col;
+  
+  return out;
+  }
+
+
+
+template<typename T1>
+arma_warn_unused
+inline
+typename enable_if2< (is_arma_type<T1>::value && is_same_type<uword,typename T1::elem_type>::yes), umat >::result
+ind2sub(const SizeMat& s, const T1& indices)
+  {
+  arma_extra_debug_sigprint();
+  
+  const uword s_n_rows = s.n_rows;
+  const uword s_n_elem = s_n_rows * s.n_cols;
+  
+  const Proxy<T1> P(indices);
+  
+  const uword P_n_rows = P.get_n_rows();
+  const uword P_n_cols = P.get_n_cols();
+  const uword P_n_elem = P.get_n_elem();
+  
+  const bool P_is_empty = (P_n_elem == 0);
+  const bool P_is_vec   = ((P_n_rows == 1) || (P_n_cols == 1));
+  
+  arma_debug_check( ((P_is_empty == false) && (P_is_vec == false)), "ind2sub(): parameter 'indices' must be a vector" );
+  
+  umat out(2,P_n_elem);
+  
+  if(Proxy<T1>::use_at == false)
+    {
+    typename Proxy<T1>::ea_type Pea = P.get_ea();
+    
+    for(uword count=0; count < P_n_elem; ++count)
+      {
+      const uword i = Pea[count];
+      
+      arma_debug_check( (i >= s_n_elem), "ind2sub(): index out of range" );
+      
+      const uword row = i % s_n_rows;
+      const uword col = i / s_n_rows;
+      
+      uword* out_colptr = out.colptr(count);
+      
+      out_colptr[0] = row;
+      out_colptr[1] = col;
+      }
+    }
+  else
+    {
+    if(P_n_rows == 1)
+      {
+      for(uword count=0; count < P_n_cols; ++count)
+        {
+        const uword i = P.at(0,count);
+        
+        arma_debug_check( (i >= s_n_elem), "ind2sub(): index out of range" );
+        
+        const uword row = i % s_n_rows;
+        const uword col = i / s_n_rows;
+        
+        uword* out_colptr = out.colptr(count);
+        
+        out_colptr[0] = row;
+        out_colptr[1] = col;
+        }
+      }
+    else
+    if(P_n_cols == 1)
+      {
+      for(uword count=0; count < P_n_rows; ++count)
+        {
+        const uword i = P.at(count,0);
+        
+        arma_debug_check( (i >= s_n_elem), "ind2sub(): index out of range" );
+        
+        const uword row = i % s_n_rows;
+        const uword col = i / s_n_rows;
+        
+        uword* out_colptr = out.colptr(count);
+        
+        out_colptr[0] = row;
+        out_colptr[1] = col;
+        }
+      }
+    }
   
   return out;
   }
@@ -435,20 +529,67 @@ ind2sub(const SizeCube& s, const uword i)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (i >= (s.n_rows * s.n_cols * s.n_slices) ), "ind2sub(): index out of range" );
+  const uword s_n_rows       = s.n_rows;
+  const uword s_n_elem_slice = s_n_rows * s.n_cols;
   
-  const uword n_elem_slice = s.n_rows * s.n_cols;
+  arma_debug_check( (i >= (s_n_elem_slice * s.n_slices) ), "ind2sub(): index out of range" );
   
-  const uword slice  = i / n_elem_slice;
-  const uword j      = i - (slice * n_elem_slice);
-  const uword row    = j % s.n_rows;
-  const uword col    = j / s.n_rows;
+  const uword slice  = i / s_n_elem_slice;
+  const uword j      = i - (slice * s_n_elem_slice);
+  const uword row    = j % s_n_rows;
+  const uword col    = j / s_n_rows;
   
   uvec out(3);
   
-  out[0] = row;
-  out[1] = col;
-  out[2] = slice;
+  uword* out_mem = out.memptr();
+  
+  out_mem[0] = row;
+  out_mem[1] = col;
+  out_mem[2] = slice;
+  
+  return out;
+  }
+
+
+
+template<typename T1>
+arma_warn_unused
+inline
+typename enable_if2< (is_arma_type<T1>::value && is_same_type<uword,typename T1::elem_type>::yes), umat >::result
+ind2sub(const SizeCube& s, const T1& indices)
+  {
+  arma_extra_debug_sigprint();
+  
+  const uword s_n_rows       = s.n_rows;
+  const uword s_n_elem_slice = s_n_rows * s.n_cols;
+  const uword s_n_elem       = s.n_slices * s_n_elem_slice;
+    
+  const quasi_unwrap<T1> U(indices);
+  
+  arma_debug_check( ((U.M.is_empty() == false) && (U.M.is_vec() == false)), "ind2sub(): parameter 'indices' must be a vector" );
+  
+  const uword  U_n_elem = U.M.n_elem;
+  const uword* U_mem    = U.M.memptr();
+  
+  umat out(3,U_n_elem);
+  
+  for(uword count=0; count < U_n_elem; ++count)
+    {
+    const uword i = U_mem[count];
+    
+    arma_debug_check( (i >= s_n_elem), "ind2sub(): index out of range" );
+    
+    const uword slice  = i / s_n_elem_slice;
+    const uword j      = i - (slice * s_n_elem_slice);
+    const uword row    = j % s_n_rows;
+    const uword col    = j / s_n_rows;
+    
+    uword* out_colptr = out.colptr(count);
+    
+    out_colptr[0] = row;
+    out_colptr[1] = col;
+    out_colptr[2] = slice;
+    }
   
   return out;
   }
@@ -462,9 +603,50 @@ sub2ind(const SizeMat& s, const uword row, const uword col)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( ((row >= s.n_rows) || (col >= s.n_cols)), "sub2ind(): subscript out of range" );
+  const uword s_n_rows = s.n_rows;
   
-  return uword(row + col*s.n_rows);
+  arma_debug_check( ((row >= s_n_rows) || (col >= s.n_cols)), "sub2ind(): subscript out of range" );
+  
+  return uword(row + col*s_n_rows);
+  }
+
+
+
+template<typename T1>
+arma_warn_unused
+inline
+uvec
+sub2ind(const SizeMat& s, const Base<uword,T1>& subscripts)
+  {
+  arma_extra_debug_sigprint();
+  
+  const uword s_n_rows = s.n_rows;
+  const uword s_n_cols = s.n_cols;
+  
+  const unwrap<T1> U(subscripts.get_ref());
+  
+  arma_debug_check( (U.M.n_rows != 2), "sub2ind(): matrix of subscripts must have 2 rows" );
+  
+  const uword U_M_n_cols = U.M.n_cols;
+  
+  uvec out(U_M_n_cols);
+  
+        uword* out_mem = out.memptr();
+  const uword* U_M_mem = U.M.memptr();
+  
+  for(uword count=0; count < U_M_n_cols; ++count)
+    {
+    const uword row = U_M_mem[0];
+    const uword col = U_M_mem[1];
+    
+    U_M_mem += 2; // next column
+    
+    arma_debug_check( ((row >= s_n_rows) || (col >= s_n_cols)), "sub2ind(): subscript out of range" );
+    
+    out_mem[count] = uword(row + col*s_n_rows);
+    }
+  
+  return out;
   }
 
 
@@ -476,9 +658,53 @@ sub2ind(const SizeCube& s, const uword row, const uword col, const uword slice)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( ((row >= s.n_rows) || (col >= s.n_cols) || (slice >= s.n_slices)), "sub2ind(): subscript out of range" );
+  const uword s_n_rows = s.n_rows;
+  const uword s_n_cols = s.n_cols;
   
-  return uword( (slice * s.n_rows * s.n_cols) + (col * s.n_rows) + row );
+  arma_debug_check( ((row >= s_n_rows) || (col >= s_n_cols) || (slice >= s.n_slices)), "sub2ind(): subscript out of range" );
+  
+  return uword( (slice * s_n_rows * s_n_cols) + (col * s_n_rows) + row );
+  }
+
+
+
+template<typename T1>
+arma_warn_unused
+inline
+uvec
+sub2ind(const SizeCube& s, const Base<uword,T1>& subscripts)
+  {
+  arma_extra_debug_sigprint();
+  
+  const uword s_n_rows   = s.n_rows;
+  const uword s_n_cols   = s.n_cols;
+  const uword s_n_slices = s.n_slices;
+  
+  const unwrap<T1> U(subscripts.get_ref());
+  
+  arma_debug_check( (U.M.n_rows != 3), "sub2ind(): matrix of subscripts must have 3 rows" );
+  
+  const uword U_M_n_cols = U.M.n_cols;
+  
+  uvec out(U_M_n_cols);
+  
+        uword* out_mem = out.memptr();
+  const uword* U_M_mem = U.M.memptr();
+  
+  for(uword count=0; count < U_M_n_cols; ++count)
+    {
+    const uword row   = U_M_mem[0];
+    const uword col   = U_M_mem[1];
+    const uword slice = U_M_mem[2];
+    
+    U_M_mem += 3; // next column
+    
+    arma_debug_check( ((row >= s_n_rows) || (col >= s_n_cols) || (slice >= s_n_slices)), "sub2ind(): subscript out of range" );
+    
+    out_mem[count] = uword( (slice * s_n_rows * s_n_cols) + (col * s_n_rows) + row );
+    }
+  
+  return out;
   }
 
 
