@@ -1,9 +1,11 @@
-// Copyright (C) 2014-2015 Conrad Sanderson
-// Copyright (C) 2014-2015 NICTA (www.nicta.com.au)
+// Copyright (C) 2014-2016 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
+// -------------------------------------------------------------------
+// 
+// Written by Conrad Sanderson - http://conradsanderson.id.au
 
 
 //! \addtogroup fn_normalise
@@ -12,6 +14,7 @@
 
 
 template<typename T1>
+arma_warn_unused
 inline
 typename
 enable_if2
@@ -37,6 +40,7 @@ normalise
 
 
 template<typename T1>
+arma_warn_unused
 inline
 typename
 enable_if2
