@@ -1,15 +1,18 @@
-// Copyright (C) 2008-2015 Conrad Sanderson
-// Copyright (C) 2008-2015 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2016 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
+// -------------------------------------------------------------------
+// 
+// Written by Conrad Sanderson - http://conradsanderson.id.au
 
 
 //! \addtogroup fn_randu
 //! @{
 
 
+arma_warn_unused
 inline
 double
 randu()
@@ -19,6 +22,7 @@ randu()
 
 
 template<typename eT>
+arma_warn_unused
 inline
 typename arma_scalar_only<eT>::result
 randu()
@@ -29,6 +33,7 @@ randu()
 
 
 //! Generate a vector with all elements set to random values in the [0,1] interval (uniform distribution)
+arma_warn_unused
 arma_inline
 const Gen<vec, gen_randu>
 randu(const uword n_elem)
@@ -41,6 +46,7 @@ randu(const uword n_elem)
 
 
 template<typename obj_type>
+arma_warn_unused
 arma_inline
 const Gen<obj_type, gen_randu>
 randu(const uword n_elem, const arma_empty_class junk1 = arma_empty_class(), const typename arma_Mat_Col_Row_only<obj_type>::result* junk2 = 0)
@@ -62,6 +68,7 @@ randu(const uword n_elem, const arma_empty_class junk1 = arma_empty_class(), con
 
 
 //! Generate a dense matrix with all elements set to random values in the [0,1] interval (uniform distribution)
+arma_warn_unused
 arma_inline
 const Gen<mat, gen_randu>
 randu(const uword n_rows, const uword n_cols)
@@ -73,6 +80,7 @@ randu(const uword n_rows, const uword n_cols)
 
 
 
+arma_warn_unused
 arma_inline
 const Gen<mat, gen_randu>
 randu(const SizeMat& s)
@@ -85,6 +93,7 @@ randu(const SizeMat& s)
 
 
 template<typename obj_type>
+arma_warn_unused
 arma_inline
 const Gen<obj_type, gen_randu>
 randu(const uword n_rows, const uword n_cols, const typename arma_Mat_Col_Row_only<obj_type>::result* junk = 0)
@@ -108,6 +117,7 @@ randu(const uword n_rows, const uword n_cols, const typename arma_Mat_Col_Row_on
 
 
 template<typename obj_type>
+arma_warn_unused
 arma_inline
 const Gen<obj_type, gen_randu>
 randu(const SizeMat& s, const typename arma_Mat_Col_Row_only<obj_type>::result* junk = 0)
@@ -120,6 +130,7 @@ randu(const SizeMat& s, const typename arma_Mat_Col_Row_only<obj_type>::result*
 
 
 
+arma_warn_unused
 arma_inline
 const GenCube<cube::elem_type, gen_randu>
 randu(const uword n_rows, const uword n_cols, const uword n_slices)
@@ -131,6 +142,7 @@ randu(const uword n_rows, const uword n_cols, const uword n_slices)
 
 
 
+arma_warn_unused
 arma_inline
 const GenCube<cube::elem_type, gen_randu>
 randu(const SizeCube& s)
@@ -143,6 +155,7 @@ randu(const SizeCube& s)
 
 
 template<typename cube_type>
+arma_warn_unused
 arma_inline
 const GenCube<typename cube_type::elem_type, gen_randu>
 randu(const uword n_rows, const uword n_cols, const uword n_slices, const typename arma_Cube_only<cube_type>::result* junk = 0)
@@ -156,6 +169,7 @@ randu(const uword n_rows, const uword n_cols, const uword n_slices, const typena
 
 
 template<typename cube_type>
+arma_warn_unused
 arma_inline
 const GenCube<typename cube_type::elem_type, gen_randu>
 randu(const SizeCube& s, const typename arma_Cube_only<cube_type>::result* junk = 0)
