@@ -1,10 +1,12 @@
-// Copyright (C) 2009-2013 Conrad Sanderson
-// Copyright (C) 2009-2013 NICTA (www.nicta.com.au)
-// Copyright (C) 2009-2010 Dimitrios Bouzas
+// Copyright (C) 2009-2016 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
+// -------------------------------------------------------------------
+// 
+// Written by Conrad Sanderson - http://conradsanderson.id.au
+// Written by Dimitrios Bouzas
 
 
 //! \addtogroup glue_kron
@@ -28,6 +30,8 @@ glue_kron::direct_kron(Mat<eT>& out, const Mat<eT>& A, const Mat<eT>& B)
   
   out.set_size(A_rows*B_rows, A_cols*B_cols);
   
+  if(out.is_empty())  { return; }
+  
   for(uword j = 0; j < A_cols; j++)
     {
     for(uword i = 0; i < A_rows; i++)
@@ -58,6 +62,8 @@ glue_kron::direct_kron(Mat< std::complex<T> >& out, const Mat< std::complex<T> >
   
   out.set_size(A_rows*B_rows, A_cols*B_cols);
   
+  if(out.is_empty())  { return; }
+  
   Mat<eT> tmp_B = conv_to< Mat<eT> >::from(B);
   
   for(uword j = 0; j < A_cols; j++)
@@ -88,6 +94,8 @@ glue_kron::direct_kron(Mat< std::complex<T> >& out, const Mat<T>& A, const Mat<
   
   out.set_size(A_rows*B_rows, A_cols*B_cols);
   
+  if(out.is_empty())  { return; }
+  
   for(uword j = 0; j < A_cols; j++)
     {
     for(uword i = 0; i < A_rows; i++)
