@@ -348,7 +348,7 @@ op_min::apply_noalias(Cube<eT>& out, const Cube<eT>& X, const uword dim, const t
 
 
 template<typename eT>
-inline 
+inline
 eT
 op_min::direct_min(const eT* const X, const uword n_elem)
   {
@@ -422,12 +422,12 @@ op_min::direct_min(const eT* const X, const uword n_elem, uword& index_of_min_va
   index_of_min_val = best_index;
   
   return min_val;
-  }  
+  }
 
 
 
 template<typename eT>
-inline 
+inline
 eT
 op_min::direct_min(const Mat<eT>& X, const uword row)
   {
@@ -539,7 +539,7 @@ op_min::min(const Base<typename T1::elem_type,T1>& X)
   
   eT min_val = priv::most_pos<eT>();
   
-  if(Proxy<T1>::prefer_at_accessor == false)
+  if(Proxy<T1>::use_at == false)
     {
     typedef typename Proxy<T1>::ea_type ea_type;
     
@@ -616,6 +616,73 @@ op_min::min(const Base<typename T1::elem_type,T1>& X)
 
 
 
+template<typename T1>
+inline
+typename arma_not_cx<typename T1::elem_type>::result
+op_min::min(const BaseCube<typename T1::elem_type,T1>& X)
+  {
+  arma_extra_debug_sigprint();
+  
+  typedef typename T1::elem_type eT;
+  
+  const ProxyCube<T1> P(X.get_ref());
+  
+  const uword n_elem = P.get_n_elem();
+  
+  if(n_elem == 0)
+    {
+    arma_debug_check(true, "min(): object has no elements");
+    
+    return Datum<eT>::nan;
+    }
+  
+  eT min_val = priv::most_pos<eT>();
+  
+  if(ProxyCube<T1>::use_at == false)
+    {
+    typedef typename ProxyCube<T1>::ea_type ea_type;
+    
+    ea_type A = P.get_ea();
+    
+    uword i,j;
+    
+    for(i=0, j=1; j<n_elem; i+=2, j+=2)
+      {
+      const eT tmp_i = A[i];
+      const eT tmp_j = A[j];
+      
+      if(tmp_i < min_val) { min_val = tmp_i; }
+      if(tmp_j < min_val) { min_val = tmp_j; }
+      }
+    
+    if(i < n_elem)
+      {
+      const eT tmp_i = A[i];
+      
+      if(tmp_i < min_val) { min_val = tmp_i; }
+      }
+    }
+  else
+    {
+    const uword n_rows   = P.get_n_rows();
+    const uword n_cols   = P.get_n_cols();
+    const uword n_slices = P.get_n_slices();
+    
+    for(uword slice=0; slice < n_slices; ++slice)
+    for(uword   col=0;   col < n_cols;   ++col  )
+    for(uword   row=0;   row < n_rows;   ++row  )
+      {
+      const eT tmp = P.at(row,col,slice);
+
+      if(tmp < min_val) { min_val = tmp; }
+      }
+    }
+  
+  return min_val;
+  }
+
+
+
 template<typename T1>
 inline
 typename arma_not_cx<typename T1::elem_type>::result
@@ -637,7 +704,7 @@ op_min::min_with_index(const Proxy<T1>& P, uword& index_of_min_val)
   eT    best_val   = priv::most_pos<eT>();
   uword best_index = 0;
   
-  if(Proxy<T1>::prefer_at_accessor == false)
+  if(Proxy<T1>::use_at == false)
     {
     typedef typename Proxy<T1>::ea_type ea_type;
     
@@ -697,8 +764,69 @@ op_min::min_with_index(const Proxy<T1>& P, uword& index_of_min_val)
 
 
 
+template<typename T1>
+inline
+typename arma_not_cx<typename T1::elem_type>::result
+op_min::min_with_index(const ProxyCube<T1>& P, uword& index_of_min_val)
+  {
+  arma_extra_debug_sigprint();
+  
+  typedef typename T1::elem_type eT;
+  
+  const uword n_elem = P.get_n_elem();
+  
+  if(n_elem == 0)
+    {
+    arma_debug_check(true, "min(): object has no elements");
+    
+    return Datum<eT>::nan;
+    }
+  
+  eT    best_val   = priv::most_pos<eT>();
+  uword best_index = 0;
+  
+  if(ProxyCube<T1>::use_at == false)
+    {
+    typedef typename ProxyCube<T1>::ea_type ea_type;
+    
+    ea_type A = P.get_ea();
+    
+    for(uword i=0; i < n_elem; ++i)
+      {
+      const eT tmp = A[i];
+      
+      if(tmp < best_val)  { best_val = tmp;  best_index = i; }
+      }
+    }
+  else
+    {
+    const uword n_rows   = P.get_n_rows();
+    const uword n_cols   = P.get_n_cols();
+    const uword n_slices = P.get_n_slices();
+    
+    uword count = 0;
+    
+    for(uword slice=0; slice < n_slices; ++slice)
+    for(uword   col=0;   col < n_cols;   ++col  )
+    for(uword   row=0;   row < n_rows;   ++row  )
+      {
+      const eT tmp = P.at(row,col,slice);
+      
+      if(tmp < best_val)  { best_val = tmp;  best_index = count; }
+      
+      ++count;
+      }
+    }
+  
+  index_of_min_val = best_index;
+  
+  return best_val;
+  }
+
+
+
 template<typename T>
-inline 
+inline
 std::complex<T>
 op_min::direct_min(const std::complex<T>* const X, const uword n_elem)
   {
@@ -724,7 +852,7 @@ op_min::direct_min(const std::complex<T>* const X, const uword n_elem)
 
 
 template<typename T>
-inline 
+inline
 std::complex<T>
 op_min::direct_min(const std::complex<T>* const X, const uword n_elem, uword& index_of_min_val)
   {
@@ -761,7 +889,7 @@ op_min::direct_min(const Mat< std::complex<T> >& X, const uword row)
   const uword X_n_cols = X.n_cols;
   
   uword index   = 0;
-  T   min_val = priv::most_pos<T>();
+  T     min_val = priv::most_pos<T>();
   
   for(uword col=0; col<X_n_cols; ++col)
     {
@@ -872,7 +1000,7 @@ op_min::min(const Base<typename T1::elem_type,T1>& X)
   
   T min_val = priv::most_pos<T>();
   
-  if(Proxy<T1>::prefer_at_accessor == false)
+  if(Proxy<T1>::use_at == false)
     {
     typedef typename Proxy<T1>::ea_type ea_type;
     
@@ -937,6 +1065,78 @@ op_min::min(const Base<typename T1::elem_type,T1>& X)
 
 
 
+template<typename T1>
+inline
+typename arma_cx_only<typename T1::elem_type>::result
+op_min::min(const BaseCube<typename T1::elem_type,T1>& X)
+  {
+  arma_extra_debug_sigprint();
+  
+  typedef typename T1::elem_type            eT;
+  typedef typename get_pod_type<eT>::result T;
+  
+  const ProxyCube<T1> P(X.get_ref());
+  
+  const uword n_elem = P.get_n_elem();
+  
+  if(n_elem == 0)
+    {
+    arma_debug_check(true, "min(): object has no elements");
+    
+    return Datum<eT>::nan;
+    }
+  
+  T min_val = priv::most_pos<T>();
+  
+  if(ProxyCube<T1>::use_at == false)
+    {
+    typedef typename ProxyCube<T1>::ea_type ea_type;
+    
+    ea_type A = P.get_ea();
+    
+    uword index = 0;
+    
+    for(uword i=0; i<n_elem; ++i)
+      {
+      const T tmp = std::abs(A[i]);
+      
+      if(tmp < min_val)
+        {
+        min_val = tmp;
+        index   = i;
+        }
+      }
+    
+    return( A[index] );
+    }
+  else
+    {
+    const uword n_rows   = P.get_n_rows();
+    const uword n_cols   = P.get_n_cols();
+    const uword n_slices = P.get_n_slices();
+    
+    eT min_val_orig = eT(0);
+    
+    for(uword slice=0; slice < n_slices; ++slice)
+    for(uword   col=0;   col < n_cols;   ++col  )
+    for(uword   row=0;   row < n_rows;   ++row  )
+      {
+      const eT tmp_orig = P.at(row,col,slice);
+      const  T tmp      = std::abs(tmp_orig);
+      
+      if(tmp < min_val)
+        {
+        min_val      = tmp;
+        min_val_orig = tmp_orig;
+        }
+      }
+    
+    return min_val_orig;
+    }
+  }
+
+
+
 template<typename T1>
 inline
 typename arma_cx_only<typename T1::elem_type>::result
@@ -958,7 +1158,7 @@ op_min::min_with_index(const Proxy<T1>& P, uword& index_of_min_val)
   
   T best_val = priv::most_pos<T>();
   
-  if(Proxy<T1>::prefer_at_accessor == false)
+  if(Proxy<T1>::use_at == false)
     {
     typedef typename Proxy<T1>::ea_type ea_type;
     
@@ -1040,4 +1240,79 @@ op_min::min_with_index(const Proxy<T1>& P, uword& index_of_min_val)
 
 
 
+template<typename T1>
+inline
+typename arma_cx_only<typename T1::elem_type>::result
+op_min::min_with_index(const ProxyCube<T1>& P, uword& index_of_min_val)
+  {
+  arma_extra_debug_sigprint();
+  
+  typedef typename T1::elem_type            eT;
+  typedef typename get_pod_type<eT>::result T;
+  
+  const uword n_elem = P.get_n_elem();
+  
+  if(n_elem == 0)
+    {
+    arma_debug_check(true, "min(): object has no elements");
+    
+    return Datum<eT>::nan;
+    }
+  
+  T best_val = priv::most_pos<T>();
+  
+  if(ProxyCube<T1>::use_at == false)
+    {
+    typedef typename ProxyCube<T1>::ea_type ea_type;
+    
+    ea_type A = P.get_ea();
+    
+    uword best_index = 0;
+    
+    for(uword i=0; i < n_elem; ++i)
+      {
+      const T tmp = std::abs(A[i]);
+      
+      if(tmp < best_val)  { best_val = tmp;  best_index = i; }
+      }
+    
+    index_of_min_val = best_index;
+    
+    return( A[best_index] );
+    }
+  else
+    {
+    const uword n_rows   = P.get_n_rows();
+    const uword n_cols   = P.get_n_cols();
+    const uword n_slices = P.get_n_slices();
+    
+    eT    best_val_orig = eT(0);
+    uword best_index    = 0;
+    uword count         = 0;
+    
+    for(uword slice=0; slice < n_slices; ++slice)
+    for(uword   col=0;   col < n_cols;   ++col  )
+    for(uword   row=0;   row < n_rows;   ++row  )
+      {
+      const eT tmp_orig = P.at(row,col,slice);
+      const  T tmp      = std::abs(tmp_orig);
+      
+      if(tmp < best_val)
+        {
+        best_val      = tmp;
+        best_val_orig = tmp_orig;
+        best_index    = count;
+        }
+      
+      ++count;
+      }
+    
+    index_of_min_val = best_index;
+    
+    return best_val_orig;
+    }
+  }
+
+
+
 //! @}
