@@ -2212,8 +2212,8 @@ subview<eT>::diag(const sword in_id) const
   {
   arma_extra_debug_sigprint();
   
-  const uword row_offset = (in_id < 0) ? -in_id : 0;
-  const uword col_offset = (in_id > 0) ?  in_id : 0;
+  const uword row_offset = uword( (in_id < 0) ? -in_id : 0 );
+  const uword col_offset = uword( (in_id > 0) ?  in_id : 0 );
   
   arma_debug_check
     (
@@ -2762,6 +2762,90 @@ subview_col<eT>::tail(const uword N) const
 
 
 
+template<typename eT>
+inline
+arma_warn_unused
+eT
+subview_col<eT>::min() const
+  {
+  arma_extra_debug_sigprint();
+  
+  if(subview<eT>::n_elem == 0)
+    {
+    arma_debug_check(true, "min(): object has no elements");
+    
+    return Datum<eT>::nan;
+    }
+  
+  return op_min::direct_min(colmem, subview<eT>::n_elem);
+  }
+
+
+
+template<typename eT>
+inline
+arma_warn_unused
+eT
+subview_col<eT>::max() const
+  {
+  arma_extra_debug_sigprint();
+  
+  if(subview<eT>::n_elem == 0)
+    {
+    arma_debug_check(true, "max(): object has no elements");
+    
+    return Datum<eT>::nan;
+    }
+  
+  return op_max::direct_max(colmem, subview<eT>::n_elem);
+  }
+
+
+
+template<typename eT>
+inline
+arma_warn_unused
+uword
+subview_col<eT>::index_min() const
+  {
+  uword index = 0;
+  
+  if(subview<eT>::n_elem == 0)
+    {
+    arma_debug_check(true, "index_min(): object has no elements");
+    }
+  else
+    {
+    op_min::direct_min(colmem, subview<eT>::n_elem, index);
+    }
+  
+  return index;
+  }
+
+
+
+template<typename eT>
+inline
+arma_warn_unused
+uword
+subview_col<eT>::index_max() const
+  {
+  uword index = 0;
+  
+  if(subview<eT>::n_elem == 0)
+    {
+    arma_debug_check(true, "index_max(): object has no elements");
+    }
+  else
+    {
+    op_max::direct_max(colmem, subview<eT>::n_elem, index);
+    }
+  
+  return index;
+  }
+
+
+
 //
 //
 //
@@ -3130,6 +3214,54 @@ subview_row<eT>::tail(const uword N) const
 
 
 
+template<typename eT>
+inline
+arma_warn_unused
+uword
+subview_row<eT>::index_min() const
+  {
+  const Proxy< subview_row<eT> > P(*this);
+  
+  uword index = 0;
+  
+  if(P.get_n_elem() == 0)
+    {
+    arma_debug_check(true, "index_min(): object has no elements");
+    }
+  else
+    {
+    op_min::min_with_index(P, index);
+    }
+  
+  return index;
+  }
+
+
+
+template<typename eT>
+inline
+arma_warn_unused
+uword
+subview_row<eT>::index_max() const
+  {
+  const Proxy< subview_row<eT> > P(*this);
+  
+  uword index = 0;
+  
+  if(P.get_n_elem() == 0)
+    {
+    arma_debug_check(true, "index_max(): object has no elements");
+    }
+  else
+    {
+    op_max::max_with_index(P, index);
+    }
+  
+  return index;
+  }
+
+
+
 //
 //
 //
